spacepy.toolbox.getNamedPath — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.getNamedPath

`spacepy.toolbox.` `getNamedPath`(name)

  Return the full path of a parent directory with name as the leaf

  Parameters: | name : string the name of the parent directory to locate

  Examples

  Run from a directory /mnt/projects/dream/bin/Ephem with ‘dream’ as the name, this function would return ‘/mnt/projects/dream’

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »